﻿const express = require('express');
const router = express.Router();
const Joi = require('joi');
const validateRequest = require('_middleware/validate-request');
const authorize = require('_middleware/authorize')
const gamerauthorize = require('_middleware/gamerauthorize')
const gameResultService = require('./gameresult.service');

// routes
router.post('/register', gamerauthorize(), registerSchema, register);
router.get('/', gamerauthorize(), getAll);
router.get('/current', gamerauthorize(), getCurrent);
router.get('/:id', gamerauthorize(), getById);
router.put('/:id', gamerauthorize(), updateSchema, update);
router.delete('/:id', gamerauthorize(), _delete);

module.exports = router;

function registerSchema(req, res, next) {
    const schema = Joi.object({
        gameId: Joi.string().required(),
        studentId: Joi.string().required(),
        groupId: Joi.string().required(),
        gameResult: Joi.string().required(),
        createdBy: Joi.string().required() 
    });
    validateRequest(req, next, schema);
}

function register(req, res, next) {
    gameResultService.create(req.body)
        .then(() => res.json({ message: 'Registration successful' }))
        .catch(next);
}

function getAll(req, res, next) {
    gameResultService.getAll()
        .then(gameresult => res.json(gameresult))
        .catch(next);
}

function getCurrent(req, res, next) {
    res.json(req.gameresult);
}

function getById(req, res, next) {
    gameResultService.getById(req.params.id)
        .then(gameresult => res.json(gameresult))
        .catch(next);
}

function updateSchema(req, res, next) {
    const schema = Joi.object({
        gameId: Joi.string().empty(''),
        studentId: Joi.string().empty(''),
        groupId: Joi.string().empty(''),
        gameResult: Joi.string().empty(''),
        updatedBy: Joi.string().empty(''), 
    });
    validateRequest(req, next, schema);
}

function update(req, res, next) {
    gameResultService.update(req.params.id, req.body)
        .then(gameresult => res.json(gameresult))
        .catch(next);
}

function _delete(req, res, next) {
    gameResultService.delete(req.params.id)
        .then(() => res.json({ message: 'Game Result deleted successfully' }))
        .catch(next);
}

function omitHash(game) {
    const { hash, ...userWithoutHash } = game;
    return userWithoutHash;
}