﻿const config = require('config.json');
const jwt = require('jsonwebtoken');
const bcrypt = require('bcryptjs');
const db = require('_helpers/db');

module.exports = {
    getAll,
    getById,
    create,
    update,
    delete: _delete
};

async function getAll() {
    return await db.GameResult.findAll();
}

async function getById(id) {
    return await getGameResult(id);
}

async function create(params) {
    // validate
    if (await db.GameResult.findOne({ where: { gameId: params.gameId } })) {
        throw 'gameId "' + params.gameId + '" is already exists';
    }
    
    // save Game Result
    await db.GameResult.create(params);
}

async function update(id, params) {
    const gameResult = await getGameResult(id);

    // validate
    const gameIdChanged = params.gameId && gameResult.gameId !== params.gameId;
    if (gameIdChanged && await db.Game.findOne({ where: { gameId: params.gameId } })) {
        throw 'gameId "' + params.gameId + '" is already exists';
    }

    // copy params to game results and save
    Object.assign(gameResult, params);
    await gameResult.save();

    return omitHash(gameResult.get());
}

async function _delete(id) {
    const gameResult = await getGameResult(id);
    await gameResult.destroy();
}

// helper functions
async function getGameResult(id) {
    const gameResult = await db.GameResult.findByPk(id);
    if (!gameResult) throw 'Game Result not found';
    return gameResult;
}

function omitHash(gameresult) {
    const { hash, ...userWithoutHash } = gameresult;
    return userWithoutHash;
}