﻿const datetimestampist = require('date-timestamp-ist');
const logger = require("../lib/logger");
const express = require('express');
const router = express.Router();
const Joi = require('joi');
const validateRequest = require('_middleware/validate-request');
const gamerauthorize = require('_middleware/gamerauthorize')
const gamerService = require('./gamer.service');
 
// routes
router.post('/authenticate', authenticateSchema, authenticate);
router.post('/register', registerSchema, register);
router.get('/', gamerauthorize(), getAll);
router.get('/current', gamerauthorize(), getCurrent);
router.get('/:id', gamerauthorize(), getById);
router.put('/:id', gamerauthorize(), updateSchema, update);
router.delete('/:id', gamerauthorize(), _delete);

module.exports = router;

function authenticateSchema(req, res, next) {
     const schema = Joi.object({
        email: Joi.string().required(),
        password: Joi.string().required()
    });
    logger.info('1 - datetimestampist: ' + JSON.stringify(datetimestampist));
    logger.info('2 - datetimestampist: ' + datetimestampist.getTime());

    validateRequest(req, next, schema);
}

function authenticate(req, res, next) {
    gamerService.authenticate(req.body)
        .then(parent => res.json(parent))
        .catch(next);
}

function registerSchema(req, res, next) {
    const schema = Joi.object({

        firstName: Joi.string().required(),
        lastName: Joi.string().required(),
        email: Joi.string().required(),
        password: Joi.string().min(6).required(),
        createdBy: Joi.string().required(),
    });
    validateRequest(req, next, schema);
}

function register(req, res, next) {
    gamerService.create(req.body)
        .then(() => res.json({ message: 'Gamer Registration successful' }))
        .catch(next);
}

function getAll(req, res, next) {
    gamerService.getAll()
        .then(parents => res.json(parents))
        .catch(next);
}

function getCurrent(req, res, next) {
    res.json(req.parent);
}

function getById(req, res, next) {
    gamerService.getById(req.params.id)
        .then(parent => res.json(parent))
        .catch(next);
}

function updateSchema(req, res, next) {
    const schema = Joi.object({

        firstName: Joi.string().empty(''),
        lastName: Joi.string().empty(''),
        email: Joi.string().empty(''),
        password: Joi.string().min(6).empty(''),
        updatedBy: Joi.string().empty('') 
    });
    validateRequest(req, next, schema);
}

function update(req, res, next) {
    gamerService.update(req.params.id, req.body)
        .then(parent => res.json(parent))
        .catch(next);
}

function _delete(req, res, next) {
    gamerService.delete(req.params.id)
        .then(() => res.json({ message: 'Gamer deleted successfully' }))
        .catch(next);
}