﻿const express = require('express');
const router = express.Router();
const Joi = require('joi');
const validateRequest = require('_middleware/validate-request');
const authorize = require('_middleware/authorize')
const gamerauthorize = require('_middleware/gamerauthorize')
const gameService = require('./game.service');

// routes
router.post('/register', gamerauthorize(), registerSchema, register);
router.get('/', gamerauthorize(), getAll);
router.get('/current', gamerauthorize(), getCurrent);
router.get('/:id', gamerauthorize(), getById);
router.put('/:id', gamerauthorize(), updateSchema, update);
router.delete('/:id', gamerauthorize(), _delete);

module.exports = router;

function registerSchema(req, res, next) {
    const schema = Joi.object({
        gameName: Joi.string().required(),
        gameLevel: Joi.string().required(),
        createdBy: Joi.string().required() 
    });
    validateRequest(req, next, schema);
}

function register(req, res, next) {
    gameService.create(req.body)
        .then(() => res.json({ message: 'Registration successful' }))
        .catch(next);
}

function getAll(req, res, next) {
    gameService.getAll()
        .then(games => res.json(games))
        .catch(next);
}

function getCurrent(req, res, next) {
    res.json(req.game);
}

function getById(req, res, next) {
    gameService.getById(req.params.id)
        .then(game => res.json(game))
        .catch(next);
}

function updateSchema(req, res, next) {
    const schema = Joi.object({
        gameName: Joi.string().empty(''),
        gameLevel: Joi.string().empty(''),
        updatedBy: Joi.string().empty(''), 
    });
    validateRequest(req, next, schema);
}

function update(req, res, next) {
    gameService.update(req.params.id, req.body)
        .then(game => res.json(game))
        .catch(next);
}

function _delete(req, res, next) {
    gameService.delete(req.params.id)
        .then(() => res.json({ message: 'Game deleted successfully' }))
        .catch(next);
}

function omitHash(game) {
    const { hash, ...userWithoutHash } = game;
    return userWithoutHash;
}