﻿const config = require('config.json');
const jwt = require('jsonwebtoken');
const bcrypt = require('bcryptjs');
const db = require('_helpers/db');

module.exports = {
    getAll,
    getById,
    create,
    update,
    delete: _delete
};

async function getAll() {
    return await db.Game.findAll();
}

async function getById(id) {
    return await getGame(id);
}

async function create(params) {
    // validate
    if (await db.Game.findOne({ where: { gameName: params.gameName } })) {
        throw 'gameName "' + params.gameName + '" is already taken';
    }
    
    // save Game
    await db.Game.create(params);
}

async function update(id, params) {
    const game = await getGame(id);

    // validate
    const gamenameChanged = params.gameName && game.gameName !== params.gameName;
    if (gamenameChanged && await db.Game.findOne({ where: { gameName: params.gameName } })) {
        throw 'Gamename "' + params.gameName + '" is already taken';
    }

    // copy params to game and save
    Object.assign(game, params);
    await game.save();

    return omitHash(game.get());
}

async function _delete(id) {
    const game = await getGame(id);
    await game.destroy();
}

// helper functions
async function getGame(id) {
    const game = await db.Game.findByPk(id);
    if (!game) throw 'Game not found';
    return game;
}

function omitHash(gamer) {
    const { hash, ...userWithoutHash } = gamer;
    return userWithoutHash;
}