const winston = require("winston");
const config = require('config.json');
const DailyRotateFile = require("winston-daily-rotate-file");

const logFormat = winston.format.combine(
 winston.format.colorize(),
 winston.format.timestamp(),
 winston.format.align(),
 winston.format.printf(
  info => `${info.timestamp} ${info.level}: ${info.message}`,
),);

const { logFolder, logFile, logLevel } = config.logConfig;

const transport = new DailyRotateFile({
   

 filename: logFolder + logFile,
 datePattern: 'YYYY-MM-DD-HH',
 zippedArchive: true,
 maxSize: '20m',
 maxFiles: '14d',
 prepend: true,
 level: logLevel,
});

transport.on('rotate', function (oldFilename, newFilename) {
// call function like upload to s3 or on cloud
});

const logger = winston.createLogger({
format: logFormat,
transports: [
     transport,
     new winston.transports.Console({
           level: "info",}),
]});

module.exports = logger;