﻿const datetimestampist = require('date-timestamp-ist');
const logger = require("../lib/logger");
const express = require('express');
const router = express.Router();
const Joi = require('joi');
const validateRequest = require('_middleware/validate-request');
const parentauthorize = require('_middleware/parentauthorize')
const parentService = require('./parent.service');
 
// routes
router.post('/authenticate', authenticateSchema, authenticate);
router.post('/register', registerSchema, register);
router.get('/', parentauthorize(), getAll);
router.get('/current', parentauthorize(), getCurrent);
router.get('/:id', parentauthorize(), getById);
router.put('/:id', parentauthorize(), updateSchema, update);
router.delete('/:id', parentauthorize(), _delete);

module.exports = router;

function authenticateSchema(req, res, next) {
     const schema = Joi.object({
        email: Joi.string().required(),
        password: Joi.string().required()
    });
    logger.info('1 - datetimestampist: ' + JSON.stringify(datetimestampist));
    logger.info('2 - datetimestampist: ' + datetimestampist.getTime());

    validateRequest(req, next, schema);
}

function authenticate(req, res, next) {
    parentService.authenticate(req.body)
        .then(parent => res.json(parent))
        .catch(next);
}

function registerSchema(req, res, next) {
    const schema = Joi.object({

        firstName: Joi.string().required(),
        lastName: Joi.string().required(),
        email: Joi.string().required(),
        password: Joi.string().min(6).required(),
        country: Joi.string().required(),
        timeZone: Joi.string().required(),
        is_agreed: Joi.string().required(),
        created_by: Joi.string().required() 
    
    });
    validateRequest(req, next, schema);
}

function register(req, res, next) {
    parentService.create(req.body)
        .then(() => res.json({ message: 'Parent Registration successful' }))
        .catch(next);
}

function getAll(req, res, next) {
    parentService.getAll()
        .then(parents => res.json(parents))
        .catch(next);
}

function getCurrent(req, res, next) {
    res.json(req.parent);
}

function getById(req, res, next) {
    parentService.getById(req.params.id)
        .then(parent => res.json(parent))
        .catch(next);
}

function updateSchema(req, res, next) {
    const schema = Joi.object({

        firstName: Joi.string().empty(''),
        lastName: Joi.string().empty(''),
        email: Joi.string().empty(''),
        password: Joi.string().min(6).empty(''),
        country: Joi.string().empty(''),
        timeZone: Joi.string().empty(''),
        is_agreed: Joi.string().empty(''),
        updated_by: Joi.string().empty(''),

    });
    validateRequest(req, next, schema);
}

function update(req, res, next) {
    parentService.update(req.params.id, req.body)
        .then(parent => res.json(parent))
        .catch(next);
}

function _delete(req, res, next) {
    parentService.delete(req.params.id)
        .then(() => res.json({ message: 'Parent deleted successfully' }))
        .catch(next);
}