﻿const config = require('config.json');
const jwt = require('jsonwebtoken');
const bcrypt = require('bcryptjs');
const db = require('_helpers/db');
const sendEmail = require('lib/send-email');

module.exports = {
    authenticate,
    getAll,
    getById,
    create,
    update,
    delete: _delete
};

async function authenticate({ email, password }) {
    const parent = await db.Parent.scope('withHash').findOne({ where: { email } });

    if (!parent || !(await bcrypt.compare(password, parent.hash)))
        throw 'email or password is incorrect';

    console.log('parent: ' + JSON.stringify(parent));
        
    // authentication successful
    const token = jwt.sign({ sub: parent.id }, config.secret, { expiresIn: '7d' });
    return { ...omitHash(basicDetails(parent)), token };
}

async function getAll() {
    return await db.Parent.findAll();
}

async function getById(id) {
    return await getParent(id);
}

async function create(params) {
    // validate
    if (await db.Parent.findOne({ where: { email: params.email } })) {
        throw 'Email "' + params.email + '" already registered';
    }

    // hash password
    if (params.password) {
        params.hash = await bcrypt.hash(params.password, 10);
    }

    // save parent
    await db.Parent.create(params);

     // send email
     await sendVerificationEmail(params);  
}


async function sendVerificationEmail(parent) {
     

    await sendEmail({
        to: parent.email,
        subject: 'Thansk for Sign-up',
        html: `<p>Thanks for registering!</p>`
    });
}

async function update(id, params) {
    const parent = await getParent(id);

    // validate
    const emailChanged = params.email && parent.email !== params.email;
    if (emailChanged && await db.Parent.findOne({ where: { email: params.email } })) {
        throw 'Email "' + params.email + '" is already taken';
    }

    // hash password if it was entered
    if (params.password) {
        params.hash = await bcrypt.hash(params.password, 10);
    }

    // copy params to parent and save
    Object.assign(parent, params);
    await parent.save();

    return omitHash(parent.get());
}

async function _delete(id) {
    const parent = await getParent(id);
    await parent.destroy();
}

// helper functions

async function getParent(id) {
    const parent = await db.Parent.findByPk(id);
    if (!parent) throw 'Parent not found';
    return parent;
}

function omitHash(parent) {
    const { hash, ...userWithoutHash } = parent;
    return userWithoutHash;
}

function basicDetails(parent) {
    const { firstName, lastName, email, created, updated, isVerified } = parent;
    return { firstName, lastName, email, created, updated, isVerified };
}